@@ -81,6 +81,28 @@ int main(int argc, char **argv)
       fputs("dap: no files to process\n", stderr);
       exit(1);
     }
+  if (argc <= 1 || (!strcmp(argv[1], "--help") || !strcmp(argv[1], "-h")))
+    {
+      fputs("Usage:\ndap [-k] [-d] FILE1.c [ FILE2.c ... ] [-a ARG1 ...]\n", stderr);
+      fputs("dap [--keep] [--debug] FILE1.c [ FILE2.c ... ] [--args] ARG1 ...]\n", stderr);
+      fputs("dap [-k] [-d] FILE1.sbs [ FILE2.c ... ]\n", stderr);
+      fputs("dap [--keep] [--debug] FILE1.sbs [ FILE2.c ... ]\n", stderr);
+      fputs("\nReport bugs to <bug-dap@gnu.org>\n", stderr);
+      exit(1);
+    }
+  else if (argc == 2 && argv[1][0] == '-')
+    {
+      if (!strcmp(argv[1], "--version") || !strcmp(argv[1], "-v"))
+	{
+	  fputs("Dap 3.1\n", stderr);
+	  exit(1);
+	}
+      else
+	{
+	  fprintf(stderr, "dap: bad option: %s\n", argv[0]);
+	  exit(1);
+	}
+    }
   if (!(editor = ecopy(getenv("DAPEDITOR"))))
     editor = ED;
   if (!(edopts = ecopy(getenv("DAPEDOPTS"))))
@@ -133,7 +155,7 @@ void edrun(int argc, char **argv)
       exit(1);
     }
   a = 0;
-  for (argstart = 1; argv[argstart][0] == '-'; argstart++)
+  for (argstart = 1; argstart < argc && argv[argstart][0] == '-'; argstart++)
     ;
   arg[a++] = argcpy(argv[argstart], 0);
   a += parseopts(edopts, arg + a);
