@@ -1601,7 +1601,7 @@ void dataset(char oldname[], char newname[], char action[])
 		  else
 		    {
 		      fprintf(dap_err,
-			      "(dataset) too many levels for c\%s\n",
+			      "(dataset) too many levels for \%s\n",
 			      dap_obs[dap_ono].do_nam[classv[c]]);
 		      exit(1);
 		    }
