@@ -820,8 +820,21 @@ static pict *show1(pict *p)
 					  else		/* count full-sized character */
 		  nfull += 1.0;
 				/* copy bare text, no super/sub-script marks, into baret */
+		  /* except if ( ), need to escape! */
 		  if (i < dap_maxtxt)
-		    baret[i++] = p->pict_txt[t][tc];
+		    {
+		      if (p->pict_txt[t][tc] == '(' || p->pict_txt[t][tc] == ')')
+			{ /* parens need escape */
+			  baret[i++] = '\\';
+			  if (i == dap_maxtxt)
+			    {
+			      fprintf(dap_err, "(show1) Text too long: %s\n",
+				      p->pict_txt[t]);
+			      exit(1);
+			    }
+			}
+		      baret[i++] = p->pict_txt[t][tc];
+		    }
 		  else
 		    {
 		      fprintf(dap_err, "(show1) Text too long: %s\n",
